@@ -9,9 +9,9 @@ from pathlib import Path
 
 from synthaser import (
     search,
-    rpsblast,
     models,
     parsers,
+    download,
 )
 from synthaser.plot import plot_synthases
 
@@ -45,9 +45,6 @@ def synthaser(
     results_file=None,
 ):
     """Run synthaser."""
-
-    LOG.info("Starting synthaser")
-
     # Set flag to prevent re-writing the JSON we load from
     _json_loaded = False
 
@@ -57,24 +54,27 @@ def synthaser(
             synthases = models.SynthaseContainer.from_json(fp)
         _json_loaded = True
     else:
-        synthases = search.search(
-            mode=mode,
-            query_file=query_file,
-            query_ids=query_ids,
-            cdsid=cdsid,
-            domain_file=domain_file,
-            classify_file=classify_file,
-            results_file=results_file,
-            database=database,
-            smode=smode,
-            useid1=useid1,
-            compbasedadj=compbasedadj,
-            filter=filter,
-            evalue=evalue,
-            maxhit=maxhit,
-            dmode=dmode,
-        )
-
+        try:
+            synthases = search.search(
+                mode=mode,
+                query_file=query_file,
+                query_ids=query_ids,
+                cdsid=cdsid,
+                domain_file=domain_file,
+                classify_file=classify_file,
+                results_file=results_file,
+                database=database,
+                smode=smode,
+                useid1=useid1,
+                compbasedadj=compbasedadj,
+                filter=filter,
+                evalue=evalue,
+                maxhit=maxhit,
+                dmode=dmode,
+            )
+        except ValueError:
+            LOG.exception("Search failed! Exiting...")
+            return
     if long_form:
         print(synthases.to_long(), flush=True, file=output)
     else:
@@ -90,20 +90,27 @@ def synthaser(
         plot = None if plot is True else plot
         plot_synthases(synthases, plot)
 
-    LOG.info("Finished synthaser")
-
 
 def main():
+    LOG.info("Starting synthaser")
+
     args = parsers.parse_args(sys.argv[1:])
 
-    if args.subcommand == "getdb":
-        rpsblast.getdb(args.database, args.folder)
+    if args.command == "getdb":
+        download.getdb(args.database, args.folder)
 
-    elif args.subcommand == "getseq":
+    elif args.command == "getseq":
         container = search.prepare_input(query_ids=args.sequence_ids)
         print(container.to_fasta(), file=args.output)
 
-    elif args.subcommand == "search":
+    elif args.command == "genbank":
+        from synthaser import genbank
+        genbank.convert(
+            args.genbank,
+            antismash=args.antismash
+        )
+
+    elif args.command == "search":
         synthaser(
             query_file=args.query_file,
             query_ids=args.query_ids,
@@ -126,6 +133,21 @@ def main():
             results_file=args.results_file,
         )
 
+    elif args.command == "extract":
+        from synthaser import extract
+        with open(args.session) as fp:
+            synthases = models.SynthaseContainer.from_json(fp)
+        extract.extract(
+            synthases,
+            args.prefix,
+            types=args.types,
+            classes=args.classes,
+            families=args.families,
+            mode=args.mode,
+        )
+
+    LOG.info("Done!")
+
 
 if __name__ == "__main__":
     main()
